@@ -102,8 +102,11 @@ class Production:  # pragma: no cover pylint: disable=too-few-public-methods
                 PyFunceble.VERSION, return_non_digits=True
             )
 
-            if self._is_version_greater() or not PyFunceble.abstracts.Version.literally_compare(
-                PyFunceble.VERSION, self.data_version_yaml["current_version"]
+            if (
+                self._is_version_greater()
+                or not PyFunceble.abstracts.Version.literally_compare(
+                    PyFunceble.VERSION, self.data_version_yaml["current_version"]
+                )
             ):
                 # * The local version is greater than the older one.
                 # or
@@ -231,11 +234,6 @@ class Production:  # pragma: no cover pylint: disable=too-few-public-methods
             + "configuration"
             + directory_separator
             + "links.rst",
-            # We fix the urls in the db_types directory.
-            PyFunceble.CONFIG_DIRECTORY
-            + directory_separator
-            + "db_types"
-            + directory_separator,
         ]
 
         for fix_it in to_fix:
@@ -448,10 +446,13 @@ class Production:  # pragma: no cover pylint: disable=too-few-public-methods
                 "PyFunceble/%s/" % "dev": r"PyFunceble\/%s\/" % "master",
                 "=%s" % "dev": "=%s" % "master",
                 "/en/%s" % "dev": r"en\/%s" % "master",
-                "/pyfunceble-%s.png" % "dev": r"\/pyfunceble.png",
+                "/pyfunceble-%s.png" % "dev": r"\/pyfunceble-dev.png",
                 "/project/pyfunceble-%s" % "dev": r"\/project\/pyfunceble$",
-                "pypistats.org/packages/pyfunceble-%s"
-                % "dev": r"pypistats\.org\/packages\/pyfunceble$s",
+                "/badge/pyfunceble-%s\\1"
+                % "dev": r"\/badge\/pyfunceble(/month|/week|)$",
+                "/blob/%s/" % "dev": r"\/blob\/%s\/" % "master",
+                "/pypi/v/pyfunceble-%s.png" % "dev": r"\/pypi\/v\/pyfunceble\.png$",
+                "/\\1/%s/" % "dev": r"\/(logo|graphmls|gifs\/raw)\/%s\/" % "master",
             }
         elif self.is_master_version():
             # The current version is the master version.
@@ -461,10 +462,13 @@ class Production:  # pragma: no cover pylint: disable=too-few-public-methods
                 "PyFunceble/%s/" % "master": r"PyFunceble\/%s\/" % "dev",
                 "=%s" % "master": "=%s" % "dev",
                 "/en/%s" % "master": r"en\/%s" % "dev",
-                "/pyfunceble.png": r"\/pyfunceble-%s.png" % "dev",
+                "/pyfunceble-dev.png": r"\/pyfunceble-%s.png" % "dev",
                 "/project/pyfunceble": r"/project\/pyfunceble-%s$" % "dev",
-                "pypistats.org/packages/pyfunceble": r"pypistats\.org\/packages\/pyfunceble-%s$"
+                "/badge/pyfunceble\\1": r"/badge\/pyfunceble-%s(/month|/week|)$"
                 % "dev",
+                "/blob/%s/" % "master": r"\/blob\/%s\/" % "dev",
+                "/pypi/v/pyfunceble.png": r"\/pypi\/v\/pyfunceble-%s\.png$" % "dev",
+                "/\\1/%s/" % "master": r"\/(logo|graphmls|gifs\/raw)\/%s\/" % "dev",
             }
         else:
             # The current version is not the master nor the dev version.
