@@ -50,7 +50,7 @@ License:
     limitations under the License.
 """
 
-from domain2idna import get as domain2idna
+import domain2idna
 
 import PyFunceble
 
@@ -67,8 +67,10 @@ class SimpleCore(CLICore):
     def __init__(self, subject):
         super().__init__()
 
+        self.mining = PyFunceble.engine.Mining("simple")
+
         if PyFunceble.CONFIGURATION.idna_conversion:
-            self.subject = domain2idna(subject)
+            self.subject = domain2idna.domain2idna(subject)
         else:
             self.subject = subject
 
@@ -138,7 +140,17 @@ class SimpleCore(CLICore):
         self.print_header()
 
         if self.subject:
-            self.__save_in_database(self.test(self.subject, "domain"))
+            results = self.test(self.subject, "domain")
+
+            for result in results:
+                if result["status"] in PyFunceble.core.CLI.get_up_statuses():
+                    self.mining.mine(result["tested"], "domain")
+
+                self.__save_in_database(result)
+
+            for index, subject in self.mining.list_of_mined():
+                self.__save_in_database(self.test(subject, "domain"))
+                self.mining.remove(index, subject)
         else:
             self.print_nothing_to_test()
 
@@ -153,6 +165,16 @@ class SimpleCore(CLICore):
         self.print_header()
 
         if self.subject:
-            self.__save_in_database(self.test(self.subject, "url"))
+            results = self.test(self.subject, "url")
+
+            for result in results:
+                if result["status"] in PyFunceble.core.CLI.get_up_statuses():
+                    self.mining.mine(result["tested"], "url")
+
+                self.__save_in_database(result)
+
+            for index, subject in self.mining.list_of_mined():
+                self.__save_in_database(self.test(subject, "url"))
+                self.mining.remove(index, subject)
         else:
             self.print_nothing_to_test()
