@@ -50,10 +50,15 @@ License:
     limitations under the License.
 """
 
+import sys
 from datetime import datetime, timedelta
 
+from colorama import Fore, Style
+
 import PyFunceble
 
+from ..exceptions import UnableToDownload
+
 
 class DownloaderBase:
     """
@@ -115,7 +120,7 @@ class DownloaderBase:
         Updates the current download time.
         """
 
-        current_datetime = datetime.now()
+        current_datetime = datetime.utcnow()
 
         self.all_downtimes[self.DOWNTIME_INDEX] = {
             "iso": current_datetime.isoformat(),
@@ -165,11 +170,11 @@ class DownloaderBase:
 
         if (
             self.REDOWNLOAD_AFTER <= 0
-            and (datetime.now() - last_download).seconds < 3600
+            and (datetime.utcnow() - last_download).seconds < 3600
         ):
             return False
 
-        if last_download + timedelta(days=self.REDOWNLOAD_AFTER) <= datetime.now():
+        if last_download + timedelta(days=self.REDOWNLOAD_AFTER) <= datetime.utcnow():
             return True
 
         return False
@@ -181,8 +186,12 @@ class DownloaderBase:
         :rtype: str, None
         """
 
-        if self.is_last_download_expired() and PyFunceble.helpers.Download(
-            self.download_link
-        ).text(destination=self.destination):
-            self.update_downtime()
-            self.save_downtimes()
+        try:
+            if self.is_last_download_expired() and PyFunceble.helpers.Download(
+                self.download_link
+            ).text(destination=self.destination):
+                self.update_downtime()
+                self.save_downtimes()
+        except UnableToDownload as exception:
+            print(f"{Fore.RED}{Style.BRIGHT}Could not downlod {str(exception)}")
+            sys.exit(1)
